#!perl

# This file was automatically generated by Dist::Zilla::Plugin::Test::Map::Tube.

use strict; use warnings;
use Test::More;
eval "use Test::Map::Tube 0.13 tests => 2";
plan skip_all => "Test::Map::Tube 0.13 required" if $@;



use Map::Tube::Delhi; 

 ok_map(Map::Tube::Delhi->new); 

 ok_map_functions(Map::Tube::Delhi->new);

